<?php
	/*  File:       findologic.php
	 *  Version:    1.0 osc (77)
	 *  Date:       6.Mai.2009
	 *
	 *  FINDOLOGIC GmbH
	 */

	require_once("./findologic_config.inc.php");

	define("FL_SERVICE_ERROR",
		"<b>findologic Service nicht erreichbar.</b> Moegliche Ursachen: <ul>".
		"<li>Der Shop-Webserver darf nicht auf die findologic Domaene zugreifen.</li>".
		"<li>Der findologic Service ist down.</li>".
		"</ul>"
	);
	
	function curl_http_request($link, $timeout) {
		$http_response = "";
		$c = curl_init();
		curl_setopt($c, CURLOPT_URL, $link);
		curl_setopt($c, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($c, CURLOPT_TIMEOUT, $timeout);
		$http_response = curl_exec($c);
		return $http_response;
	}

	function fl_http_request($link) {
		$http_response = "";
		$handle = fopen($link, "r");
		if (!handle) {
			return FL_SERVICE_ERROR;
		} else {
			while (!feof($handle)) {
				$http_response .= fread($handle, 512);
			}
		}
		return $http_response;
	}

	function direct_http_request($link, $timeout) {
		$http_response = "";
		$url = parse_url($link);
		$handle = fsockopen($url[host], 80, $err_num, $err_msg, $timeout);
		if (!$handle) {
			return "error: $err_msg($err_num)";
		} else {
			fputs($handle, "GET $url[path]?$url[query] HTTP/1.0\n");
			fputs($handle, "Host: $url[host]\n");
			fputs($handle, "Connection: close\n\n");
			while (!feof($handle)) {
				$http_response .= fgets($handle, 512);
			}
			fclose($handle);
		}
		return $http_response;
	}

	function async_request($url) {
		$timeout = 10;
		$handle = fsockopen($url[host], 80, $err_num, $err_msg, $timeout);
		if (!$handle) {
			return "error: $err_msg($err_num)";
		} else {
			stream_set_timeout($handle, $timeout);
			fputs($handle, "GET $url[path]?$url[query] HTTP/1.0\n");
			fputs($handle, "Host: $url[host]\n");
			fputs($handle, "Connection: close\n\n");
			fclose($handle);
		}
	}

	function isAlive($url) {
		if (function_exists('curl_init')) {
			$status = curl_http_request($url."alivetest.php?shopkey=" . FL_SHOP_ID, FL_ALIVE_TEST_TIMEOUT);
			return trim($status) == "alive";
		} else {
			$status = direct_http_request($url."alivetest.php?shopkey=" . FL_SHOP_ID, FL_ALIVE_TEST_TIMEOUT);
			return substr(trim($status), -5) == "alive";
		}
	}

	if ($_GET["target"] != "") {
		// user clicked on product:
		// notify service
		$url = FL_SERVICE_URL."index.php?".
			"shop=".FL_SHOP_ID.
			"&userip=".$_SERVER["REMOTE_ADDR"].
			"&".$_SERVER["QUERY_STRING"];
		async_request($url);

		// redirect to product-page
		$productpage = urldecode($_GET["target"]);
		header("Location: $productpage");
	} else {
		// user is searching:

		// load SESSION from XT-Commerce
		require('includes/application_top.php');
//		require(DIR_WS_LANGUAGES . $language . '/' . FILENAME_ADVANCED_SEARCH);

		$doFindologicSearch = ($_SESSION["language"] == "german");
		if ($doFindologicSearch && !isAlive(FL_SERVICE_URL)) $doFindologicSearch = false;

		if ($doFindologicSearch) {
			// read parameters
			$params = str_replace(
				FL_SHOP_SEARCHBOX_NAME."=", "keywords=", $_SERVER["QUERY_STRING"]
			);

			// do http-request
			$url = FL_SERVICE_URL."index.php?".
				"shopkey=".FL_SHOP_ID.
				"&shopurl=".urlencode(FL_SHOP_URL).
				"&userip=".$_SERVER["REMOTE_ADDR"].
				"&referer=".urlencode($_SERVER['HTTP_REFERER']).
				"&revision=".FL_REVISION.
				"&".$params;
			if (function_exists('curl_init')) {
				$content = curl_http_request($url, FL_REQUEST_TIMEOUT);
			} else {
				$content = fl_http_request($url);
			}
			if (strlen($content) == 0) $doFindologicSearch = false;
		}

		if (!$doFindologicSearch) {
			//a language without support; use standard search
			$standardsearch = FL_SHOP_URL."advanced_search_result.php?".$_SERVER["QUERY_STRING"];

			//rediret to standard search
			header("Location: $standardsearch");
		} else {
?>
<!doctype html public "-//W3C//DTD HTML 4.01 Transitional//EN">
<html <?php echo HTML_PARAMS; ?>>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=<?php echo CHARSET; ?>">
<base href="<?php echo (($request_type == 'SSL') ? HTTPS_SERVER : HTTP_SERVER) . DIR_WS_CATALOG; ?>">
<title><?php echo TITLE; ?></title>
<link rel="stylesheet" type="text/css" href="stylesheet.css">
</head>
<body marginwidth="0" marginheight="0" topmargin="0" bottommargin="0" leftmargin="0" rightmargin="0">
<!-- header //-->
<?php require(DIR_WS_INCLUDES . 'header.php'); ?>
<!-- header_eof //-->

<!-- body //-->
<table border="0" width="100%" cellspacing="3" cellpadding="3">
  <tr>
    <td width="<?php echo BOX_WIDTH; ?>" valign="top"><table border="0" width="<?php echo BOX_WIDTH; ?>" cellspacing="0" cellpadding="2">
<!-- left_navigation //-->
<?php require(DIR_WS_INCLUDES . 'column_left.php'); ?>
<!-- left_navigation_eof //-->
    </table></td>
<!-- body_text //-->
    <td width="100%" valign="top"><table border="0" width="100%" cellspacing="0" cellpadding="0">
      <tr>
        <td>
<?php
			echo $content;
?>
        </td>
      </tr>
    </table></td>
<!-- body_text_eof //-->
    <td width="<?php echo BOX_WIDTH; ?>" valign="top"><table border="0" width="<?php echo BOX_WIDTH; ?>" cellspacing="0" cellpadding="2">
<!-- right_navigation //-->
<?php require(DIR_WS_INCLUDES . 'column_right.php'); ?>
<!-- right_navigation_eof //-->
    </table></td>
  </tr>
</table>
<!-- body_eof //-->

<!-- footer //-->
<?php require(DIR_WS_INCLUDES . 'footer.php'); ?>
<!-- footer_eof //-->
<br>
</body>
</html>
<?php require(DIR_WS_INCLUDES . 'application_bottom.php'); ?>

<?php
		}
	}
?>
